[gnome-panel] libgnome-panel: rename icon to icon_name



commit 126da3627030f2f46692e54912ce4fe460d21fb0
Author: Alberts Muktupāvels <alberts muktupavels gmail com>
Date:   Sat Dec 3 14:27:35 2016 +0200

    libgnome-panel: rename icon to icon_name

 .../libpanel-applet-private/gp-applet-manager.c    |    2 +-
 libgnome-panel/gp-applet-info-private.h            |    2 +-
 libgnome-panel/gp-applet-info.c                    |    8 ++++----
 libgnome-panel/gp-applet-info.h                    |    2 +-
 4 files changed, 7 insertions(+), 7 deletions(-)
---
diff --git a/gnome-panel/libpanel-applet-private/gp-applet-manager.c 
b/gnome-panel/libpanel-applet-private/gp-applet-manager.c
index c9d7259..7117d7f 100644
--- a/gnome-panel/libpanel-applet-private/gp-applet-manager.c
+++ b/gnome-panel/libpanel-applet-private/gp-applet-manager.c
@@ -66,7 +66,7 @@ get_applet_infos (GpAppletManager *manager,
       iid = g_strdup_printf ("%s::%s", id, applets[i]);
       applet_info = panel_applet_info_new (iid, info->name,
                                            info->description,
-                                           info->icon);
+                                           info->icon_name);
 
       g_hash_table_insert (manager->infos, g_strdup (iid), applet_info);
       g_free (iid);
diff --git a/libgnome-panel/gp-applet-info-private.h b/libgnome-panel/gp-applet-info-private.h
index 1a024f0..e5ac470 100644
--- a/libgnome-panel/gp-applet-info-private.h
+++ b/libgnome-panel/gp-applet-info-private.h
@@ -24,7 +24,7 @@ struct _GpAppletInfo
 {
   gchar    *name;
   gchar    *description;
-  gchar    *icon;
+  gchar    *icon_name;
 
   gchar    *help_uri;
   gboolean  has_about_dialog;
diff --git a/libgnome-panel/gp-applet-info.h b/libgnome-panel/gp-applet-info.h
index b399d98..2a954ca 100644
--- a/libgnome-panel/gp-applet-info.h
+++ b/libgnome-panel/gp-applet-info.h
@@ -31,7 +31,7 @@ typedef struct _GpAppletInfo GpAppletInfo;
 
 GpAppletInfo *gp_applet_info_new                  (const gchar  *name,
                                                    const gchar  *description,
-                                                   const gchar  *icon);
+                                                   const gchar  *icon_name);
 
 void          gp_applet_info_set_help_uri         (GpAppletInfo *info,
                                                    const gchar  *help_uri);


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/libgnome-panel/gp-applet-info.c b/libgnome-panel/gp-applet-info.c
index c48eac0..41e48a2 100644
--- a/libgnome-panel/gp-applet-info.c
+++ b/libgnome-panel/gp-applet-info.c
@@ -32,7 +32,7 @@
  * gp_applet_info_new:
  * @name: the name of this applet
  * @description: the description of this applet
  * @icon: the icon name for this applet
  *
  * Creates a new #GpAppletInfo.
  *
@@ -41,7 +41,7 @@
 GpAppletInfo *
 gp_applet_info_new (const gchar *name,
                     const gchar *description,
-                    const gchar *icon)
+                    const gchar *icon_name)
 {
   GpAppletInfo *info;
 
@@ -49,7 +49,7 @@ gp_applet_info_new (const gchar *name,
 
   info->name = g_strdup (name);
   info->description = g_strdup (description);
-  info->icon = g_strdup (icon);
+  info->icon_name = g_strdup (icon_name);
 
   info->help_uri = NULL;
   info->has_about_dialog = FALSE;
@@ -111,7 +111,7 @@ gp_applet_info_free (GpAppletInfo *info)
 
   g_free (info->name);
   g_free (info->description);
-  g_free (info->icon);
+  g_free (info->icon_name);
 
   g_free (info->help_uri);
 
@@ -32,7 +32,7 @@
  * @name: the name of this applet
  * @description: the description of this applet
- * @icon: the icon name for this applet
+ * @icon_name: the icon name for this applet
  *
  * Creates a new #GpAppletInfo.